#!/usr/bin/env python3

__all__ = ['clean']

import os
import sys
import json
from pathlib import Path

def jsonReplace(dict, key, newval):
    try:             dict[key] = newval
    except KeyError: pass

def jsonDump(file, dict):
    with open(file, 'w') as f: json.dump(dict, f, indent=1)

def clearRunCount(file):
    with open(file, 'r') as f:
        data = json.load(f)
        for cell in data["cells"]:
            jsonReplace(cell, "execution_count", None)
    jsonDump(file, data)

def clearMetaData(file):
    with open(file, 'r') as f:
        data = json.load(f)
        jsonReplace(data, "metadata", {})
    jsonDump(file, data)

def clean(file, order=True, meta=True):
    if order: clearRunCount(file)
    if meta:  clearMetaData(file)

if __name__ == "__main__":
    if len(sys.argv) <= 1:
        raise EOFError("Expected to receive a specific file name to clean")
    fn = Path(sys.argv[1])
    clean(fn)


from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='literacy',
      version='0.2.1',
      url='https://github.com/holyfiddlex/literacy',
      author='Héctor de la Rosa Prado',
      author_email='hoftherose@gmail.com',
      description='Tools for literate programming in python and jupyter notebooks, following the functionality of Fastai v2 dev https://github.com/fastai/fastai_dev',
      long_description=long_description,
      long_description_content_type="text/markdown",
      license='MIT',
      packages=['literacy'],
      scripts=['bin/literate-git-hooks', 'bin/git-hook'],
      zip_safe=False)